import type { Simplify } from 'type-fest/source/simplify.js';
import { RESTResponseToSDKResponseRenameMap, SDKRequestToRESTRequestRenameMap } from './constants.js';
/**
 * Recursively rename nested keys provided in `renameMap` in the given object.
 * Providing a list of paths to ignore will prevent renaming of keys in nested objects.
 *
 * Paths are provided in the format of 'path.to.nested.field'
 * @param payload The object to rename keys for
 * @param renameMap A map of keys to rename, where the key is the original key and the value is the new key
 * @param ignorePaths Paths of nested fields to ignore while traversing the object
 * @returns The object with renamed keys
 */
export declare function renameAllNestedKeys<T, KeyMapper extends Record<string, string>>(payload: T | undefined, renameMap: KeyMapper, ignorePaths: string[]): RenameAllNestedKeys<T, KeyMapper>;
export declare function renameKeysFromSDKRequestToRESTRequest<T>(payload: T | undefined, ignorePaths?: string[]): RenameAllNestedKeys<T, typeof SDKRequestToRESTRequestRenameMap>;
export declare function renameKeysFromRESTResponseToSDKResponse<T>(payload: T | undefined, ignorePaths?: string[]): RenameAllNestedKeys<T, typeof RESTResponseToSDKResponseRenameMap>;
type NonTransformedTypes = ArrayBufferLike | Date | RegExp | string | number | boolean | null | undefined;
type DecrementDepth = [never, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10];
export type RenameAllNestedKeys<T, KeyMapper extends Record<string, string>, Depth extends number = 10> = Depth extends never ? T : T extends NonTransformedTypes ? T : Simplify<MapKeys<{
    [P in keyof T]: T extends T[P] ? T[P] : T[] extends T[P] ? T[P] : TransformedValue<T[P], KeyMapper, DecrementDepth[Depth]>;
}, KeyMapper>>;
type TransformedValue<T, KeyMapper extends Record<string, string>, Depth extends number = 10> = T extends NonTransformedTypes ? T : T extends (infer E)[] ? TransformedArray<E, KeyMapper, Depth> : T extends object ? RenameAllNestedKeys<T, KeyMapper, Depth> : T;
interface TransformedArray<T, KeyMapper extends Record<string, string>, Depth extends number = 10> extends Array<TransformedValue<T, KeyMapper, Depth>> {
}
type MapKeys<T, M extends Record<string, string>> = KeyValueTupleToObject<ValueOf<{
    [K in keyof T]-?: [
        K extends keyof M ? (M[K] extends keyof T ? K : M[K]) : K,
        T[K]
    ];
}>>;
type KeyValueTupleToObject<T extends [keyof any, any]> = {
    [K in T[0]]: Extract<T, [K, any]>[1];
};
type ValueOf<T> = T[keyof T];
export {};
